#!/usr/bin/perl

use DataOneLdap;
use strict;

use Getopt::Long();

sub usage {
   my $message = $_[0];
   if (defined $message && length $message) {
      $message .= "\n"
         unless $message =~ /\n$/;
   }

   my $command = $0;
   $command =~ s#^.*/##;

   print STDERR (
      $message,
      "usage: $command [--help] [--id reservationId]|--all\n"
   );

   die("\n")
}

my $reservation_id;
my $all;
my $help;
my $mesg;

Getopt::Long::GetOptions(
   'id=s' => \$reservation_id,
   'all' => \$all,
   'help!' => \$help
) or usage("Invalid commmand line options.");

usage() if (defined $help);

if (defined $all)
	{
	$all = 1;
	}
elsif (! (defined $reservation_id))
	{
	usage("Invalid commmand line options. Either --id reservation_id or --all must be provided");
	}
	

my $d1Ldap = new DataOneLdap();

my $ldap = $d1Ldap->connect();


if (defined $all)
        {
	$mesg = $ldap->search(  filter=>"(objectClass=d1Reservation)", 
                        base=>"dc=org");
	}
else
	{
	$mesg = $ldap->search(  filter=>"&(objectClass=d1Reservation)(reservationId=$reservation_id)", 
                        base=>"dc=org");
	}

my @entries = $mesg->entries;
foreach my $entry (@entries) 
	{
	my $dn = $entry->dn();
	print "DN = $dn\n";
	$ldap->delete($dn);
	}

$ldap->unbind;

